##  Using the TIME Classification for Application Portfolio Assessment
Once the classification is completed, you can start creating insights out of the data by using various Reports. For example, we can create a great overview of the TIME classification in the Application Landscape report
  1. In an Application Landscape Report, apply the necessary filters to narrow down the view according to your needs
  2. From the View drop-down menu, select TIME classification. The colors depict the chosen TIME classification.
  3. You can also cluster the applications based on TIME classification from the Report Settings to visualize for easier consumption.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274139137a4410148aff870fee164767_LowRes.gif)
We can even enrich this report with Cost data being displayed simultaneously. From Report Settings, you can choose to display the Cost data on either the Left or Right property.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b47c97a44101482afefcf27c631b5_LowRes.png)
Another example: If you like to see all the applications that are marked for elimination but will cause the least impact on their business operation, you can leverage the Application Portfolio Report. Just set the X and Y axis to TIME Classification and Business Criticality to get the desired view.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27466dcc7a4410149026a6da80a0b01d_LowRes.gif)
You can learn more about obtaining insights from TIME classification through Reports in [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data?locale=en-US&state=PRODUCTION&version=CLOUD "Leverage automated TIME classification, application portfolio and landscape reports, and collaborative decision tools to streamline application rationalization and visualize cost-saving opportunities"). For instance, if you also add the cost details to the Application Fact Sheet, you can quickly develop a multidimensional view that allows you to quickly prioritize your applications for rationalization. For example, identify high-cost applications that do not adequately serve your business which are classified under Eliminate. Follow [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data?locale=en-US&state=PRODUCTION&version=CLOUD "Leverage automated TIME classification, application portfolio and landscape reports, and collaborative decision tools to streamline application rationalization and visualize cost-saving opportunities") to understand how to acquire cost outlook by using the Application Portfolio Report.
To learn more about using Reports and using them in more powerful and effective ways, check our [documentation on Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD). It is also encouraged to check out the documentation on [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") and [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.") use cases to understand how TIME classification could be useful and to get started with the use cases already.
YesNo
Send
